Preferences
===========

.. automodule:: psyneulink.core.globals.preferences.preferenceset
   :members:
   :exclude-members: PreferenceSet, Parameters, PreferenceLevel, PreferenceSetError, PreferenceEntry, PreferenceSetRegistry
